@@ -40,8 +40,7 @@ blob_detection <- function(wave,
                            min_dur = 1.5,
                            max_dur = 80,
                            min_area = 40,
-                           TBE_min = 20,
-                           TBE_max = 100,
+                           TBE = 20,
                            EDG = .9,
                            LPF,
                            HPF = 16000,
@@ -77,8 +76,7 @@ blob_detection <- function(wave,
                                sample_rate = sample_rate,
                                LPF = LPF,
                                HPF = HPF,
-                               TBE_min = TBE_min,
-                               TBE_max = TBE_max,
+                               TBE = TBE,
                                EDG = EDG,
                                FFT_size = FFT_size,
                                FFT_overlap = FFT_overlap,
@@ -180,13 +178,12 @@ blob_detection <- function(wave,
         min_area = min_area,
         LPF = LPF,
         HPF = HPF,
-        TBE_min = TBE_min,
-        TBE_max = TBE_max,
         EDG = EDG,
         FFT_size = FFT_size,
         FFT_overlap = FFT_overlap,
         blur = blur,
         bg_substract = bg_substract,
+        EDG = EDG,
         contrast_boost = contrast_boost,
         stringsAsFactors = FALSE
       )
